@@ -52,9 +52,12 @@ def UnwrapPyTree(tree):
   uwlines.sort(key=lambda x: x.lineno)
   return uwlines
 
+
 # Grammar tokens considered as whitespace for the purpose of unwrapping.
-_WHITESPACE_TOKENS = frozenset([grammar_token.NEWLINE, grammar_token.DEDENT,
-                                grammar_token.INDENT, grammar_token.ENDMARKER])
+_WHITESPACE_TOKENS = frozenset([
+    grammar_token.NEWLINE, grammar_token.DEDENT, grammar_token.INDENT,
+    grammar_token.ENDMARKER
+])
 
 
 class PyTreeUnwrapper(pytree_visitor.PyTreeVisitor):
@@ -194,8 +197,13 @@ class PyTreeUnwrapper(pytree_visitor.PyTreeVisitor):
 
   def Visit_async_funcdef(self, node):  # pylint: disable=invalid-name
     self._StartNewLine()
-    self.Visit(node.children[0])
-    for child in node.children[1].children:
+    index = 0
+    for child in node.children:
+      index += 1
+      self.Visit(child)
+      if pytree_utils.NodeName(child) == 'ASYNC':
+        break
+    for child in node.children[index].children:
       self.Visit(child)
 
   _CLASS_DEF_ELEMS = frozenset({'class'})
@@ -205,8 +213,13 @@ class PyTreeUnwrapper(pytree_visitor.PyTreeVisitor):
 
   def Visit_async_stmt(self, node):  # pylint: disable=invalid-name
     self._StartNewLine()
-    self.Visit(node.children[0])
-    for child in node.children[1].children:
+    index = 0
+    for child in node.children:
+      index += 1
+      self.Visit(child)
+      if pytree_utils.NodeName(child) == 'ASYNC':
+        break
+    for child in node.children[index].children:
       self.Visit(child)
 
   def Visit_decorators(self, node):  # pylint: disable=invalid-name
@@ -322,11 +335,15 @@ def _AdjustSplitPenalty(uwline):
 def _DetermineMustSplitAnnotation(node):
   """Enforce a split in the list if the list ends with a comma."""
   if not _ContainsComments(node):
+    if sum(1 for ch in node.children
+           if pytree_utils.NodeName(ch) == 'COMMA') < 2:
+      return
     if (not isinstance(node.children[-1], pytree.Leaf) or
         node.children[-1].value != ','):
       return
   num_children = len(node.children)
   index = 0
+  _SetMustSplitOnFirstLeaf(node.children[0])
   while index < num_children - 1:
     child = node.children[index]
     if isinstance(child, pytree.Leaf) and child.value == ',':
