@@ -143,8 +143,8 @@ class UnwrappedLine(object):
     return self.AsCode()
 
   def __repr__(self):  # pragma: no cover
-    tokens_repr = ','.join(['{0}({1!r})'.format(tok.name, tok.value)
-                            for tok in self._tokens])
+    tokens_repr = ','.join(
+        ['{0}({1!r})'.format(tok.name, tok.value) for tok in self._tokens])
     return 'UnwrappedLine(depth={0}, tokens=[{1}])'.format(self.depth,
                                                            tokens_repr)
 
@@ -231,7 +231,7 @@ def _SpaceRequiredBetween(left, right):
     # A string followed by something other than a subscript, closing bracket,
     # or dot should have a space after it.
     return True
-  if left.is_binary_op and _IsUnaryOperator(right):
+  if left.is_binary_op and lval != '**' and _IsUnaryOperator(right):
     # Space between the binary opertor and the unary operator.
     return True
   if _IsUnaryOperator(left) and _IsUnaryOperator(right):
@@ -255,6 +255,10 @@ def _SpaceRequiredBetween(left, right):
   if (format_token.Subtype.DEFAULT_OR_NAMED_ASSIGN in left.subtypes or
       format_token.Subtype.DEFAULT_OR_NAMED_ASSIGN in right.subtypes):
     # A named argument or default parameter shouldn't have spaces around it.
+    # However, a typed argument should have a space after the colon.
+    return lval == ':' or style.Get('SPACES_AROUND_DEFAULT_OR_NAMED_ASSIGN')
+  if (format_token.Subtype.VARARGS_LIST in left.subtypes or
+      format_token.Subtype.VARARGS_LIST in right.subtypes):
     return False
   if (format_token.Subtype.VARARGS_STAR in left.subtypes or
       format_token.Subtype.KWARGS_STAR_STAR in left.subtypes):
